dot-freqtab: Helper function for frequency of levels by dimensions tables

.freqtabR Documentation

Helper function for frequency of levels by dimensions tables

Description

Helper function for frequency of levels by dimensions tables

Usage

.freqtab(
  df,
  names_eq5d = NULL,
  name_fu = NULL,
  levels_fu = NULL,
  eq5d_version = NULL,
  add_summary_problems_change = TRUE
)

Arguments

df

Data frame with the EQ-5D and follow-up columns

names_eq5d

Character vector of column names for the EQ-5D dimensions

name_fu

Character string for the follow-up column. If NULL, no grouping is used, and the table reports for the total population.

levels_fu

Character vector containing the order of the values in the follow-up column. If NULL (default value), the levels will be ordered in the order of appearance in df.

eq5d_version

Version of the EQ-5D instrument

add_summary_problems_change

If set to false, the resulting dataframe does not include a row on problems change.

Value

Summary data frame.


eq5dsuite documentation built on April 11, 2026, 5:06 p.m.