dot-gen_colours: Generate colours for PCHC figures

.gen_coloursR Documentation

Generate colours for PCHC figures

Description

This internal function generates a vector of colours based on the specified base colour. Currently only green and orange colours are implemented. The wrapper is used in Figures 2.2-2.4.

Usage

.gen_colours(col, n)

Arguments

col

A character string specifying the base colour. Only "green" or "orange" is accepted.

n

A positive integer specifying the number of colours to generate.

Value

A vector of colours generated based on the specified base colour and number of colours.

Examples

# generate 10 colours for base colour "green"
.gen_colours("green", 10)
# generate 7 colours for base colour "orange"
.gen_colours("orange", 7)

eq5dsuite documentation built on April 11, 2026, 5:06 p.m.