| .getmode | R Documentation |
This function calculates the mode of a numeric or character vector. If there are multiple modes, the first one is returned. The code is taken from an R help page.
.getmode(v)
v |
A numeric or character vector. |
The mode of 'v'.
.getmode(c(1, 2, 3, 3))
.getmode(c("a", "b", "b", "c"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.