| .pchctab | R Documentation |
.pchctab: Changes in health according to the PCHC (Paretian Classification of Health Change)
.pchctab(
df,
name_id,
name_groupvar,
names_eq5d = NULL,
name_fu = NULL,
levels_fu = NULL,
add_noprobs = FALSE
)
df |
Data frame with the EQ-5D, grouping, id and follow-up columns |
name_id |
Character string for the patient id column |
name_groupvar |
Character string for the grouping column |
names_eq5d |
Character vector of column names for the EQ-5D dimensions |
name_fu |
Character string for the follow-up column |
levels_fu |
Character vector containing the order of the values in the follow-up column. If NULL (default value), the levels will be ordered in the order of appearance in df. |
add_noprobs |
if set to TRUE, level corresponding to "no problems" will be added to the table |
Summary data frame
.pchctab(df = example_data,
name_id = "id",
name_groupvar = "procedure",
name_fu = "time",
levels_fu = c('Pre-op', 'Post-op')
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.