dot-summary_mean_ci: Wrapper to calculate summary mean with 95% confidence...

.summary_mean_ciR Documentation

Wrapper to calculate summary mean with 95% confidence interval

Description

This internal function calculates summary mean and 95% confidence interval of the utility variable, which can also be grouped. The function is used in Figures 4.2-4.4.

Usage

.summary_mean_ci(df, group_by)

Arguments

df

A data frame containing a 'utility' column.

group_by

A character vector of column names to group by.

Value

A data frame with the mean, lower bound, and upper bound of the 95

Examples

df <- data.frame(group = c("A", "A", "B", "B"), 
                 utility = c(0.5, 0.7, 0.8, 0.9))
.summary_mean_ci(df, group_by = "group")

eq5dsuite documentation built on April 11, 2026, 5:06 p.m.