eq5d_profile_change_summary: eq5d_profile_change_summary: Frequency of levels by...

View source: R/eq5d_devlin.R

eq5d_profile_change_summaryR Documentation

eq5d_profile_change_summary: Frequency of levels by dimensions, by follow-up

Description

eq5d_profile_change_summary: Frequency of levels by dimensions, by follow-up

Usage

eq5d_profile_change_summary(
  df,
  names_eq5d = NULL,
  name_fu = NULL,
  levels_fu = NULL,
  eq5d_version = NULL
)

Arguments

df

Data frame with the EQ-5D and follow-up columns

names_eq5d

Character vector of column names for the EQ-5D dimensions

name_fu

Character string for the follow-up column. If NULL, the function will check if there is a column named "follow-up" or "fu", in which case the first of those will be used.

levels_fu

Character vector containing the order of the values in the follow-up column. If NULL (default value), the levels will be ordered in the order of appearance in df.

eq5d_version

Version of the EQ-5D instrument

Value

Summary data frame.

Examples

eq5d_profile_change_summary(
  df = example_data,
  names_eq5d = c("mo", "sc", "ua", "pd", "ad"),
  name_fu = "time",
  levels_fu = c("Pre-op" , "Post-op"),
  eq5d_version = "3L"
)

eq5dsuite documentation built on May 14, 2026, 5:07 p.m.