| eq5d_profile_dimension_change_table | R Documentation |
eq5d_profile_dimension_change_table: Changes in levels in each dimension, percentages of total and of type of change
eq5d_profile_dimension_change_table(
df,
name_id,
names_eq5d = NULL,
name_fu = NULL,
levels_fu = NULL
)
df |
Data frame with the EQ-5D, id and follow-up columns |
name_id |
Character string for the patient id column |
names_eq5d |
Character vector of column names for the EQ-5D dimensions |
name_fu |
Character string for the follow-up column |
levels_fu |
Character vector containing the order of the values in the follow-up column. If NULL (default value), the levels will be ordered in the order of appearance in df. |
Summary data frame
eq5d_profile_dimension_change_table(
df = example_data,
name_id = "id",
names_eq5d = c("mo", "sc", "ua", "pd", "ad"),
name_fu = "time",
levels_fu = c("Pre-op" , "Post-op")
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.