eq5d_profile_lss_utility_plot: eq5d_profile_lss_utility_plot: EQ-5D values plotted against...

eq5d_profile_lss_utility_plotR Documentation

eq5d_profile_lss_utility_plot: EQ-5D values plotted against LSS

Description

eq5d_profile_lss_utility_plot: EQ-5D values plotted against LSS

Usage

eq5d_profile_lss_utility_plot(
  df,
  names_eq5d = NULL,
  eq5d_version = NULL,
  country
)

Arguments

df

Data frame with the EQ-5D columns

names_eq5d

Character vector of column names for the EQ-5D dimensions

eq5d_version

Version of the EQ-5D instrument

country

A character string representing the name of the country. This could be in a 2-letter format, full name or short name, as specified in the country_codes datasets.

Value

Summary plot and data used for plotting

Examples

df <- data.frame(make_all_EQ_states(version = "5L"))
tmp <- eq5d_profile_lss_utility_plot(
 df, 
 names_eq5d = c("mo", "sc", "ua", "pd", "ad"), 
 eq5d_version = "5L", 
 country = "US"
)
tmp$p
tmp$plot_data

eq5dsuite documentation built on May 14, 2026, 5:07 p.m.