eq5d_profile_lss_utility_summary: eq5d_profile_lss_utility_summary: Summary statistics for the...

View source: R/eq5d_devlin.R

eq5d_profile_lss_utility_summaryR Documentation

eq5d_profile_lss_utility_summary: Summary statistics for the EQ-5D values by all the different LSSs (Level Sum Scores)

Description

eq5d_profile_lss_utility_summary: Summary statistics for the EQ-5D values by all the different LSSs (Level Sum Scores)

Usage

eq5d_profile_lss_utility_summary(
  df,
  names_eq5d = NULL,
  eq5d_version = NULL,
  country
)

Arguments

df

Data frame with the EQ-5D columns

names_eq5d

Character vector of column names for the EQ-5D dimensions

eq5d_version

Version of the EQ-5D instrument

country

A character string representing the name of the country. This could be in a 2-letter format, full name or short name, as specified in the country_codes datasets.

Value

Summary data frame

Examples

df <- data.frame(make_all_EQ_states(version = "5L"))
eq5d_profile_lss_utility_summary(
  df, 
  names_eq5d = c("mo", "sc", "ua", "pd", "ad"), 
  eq5d_version = "3L", 
  country = "US"
)

eq5dsuite documentation built on May 14, 2026, 5:07 p.m.