eq5d_utility_by_group_plot: eq5d_utility_by_group_plot: Mean EQ-5D values and 95%...

eq5d_utility_by_group_plotR Documentation

eq5d_utility_by_group_plot: Mean EQ-5D values and 95% confidence intervals: all vs by groupvar

Description

eq5d_utility_by_group_plot: Mean EQ-5D values and 95% confidence intervals: all vs by groupvar

Usage

eq5d_utility_by_group_plot(
  df,
  names_eq5d = NULL,
  name_groupvar = NULL,
  eq5d_version = NULL,
  country
)

Arguments

df

Data frame with the EQ-5D and grouping columns

names_eq5d

Character vector of column names for the EQ-5D dimensions

name_groupvar

Character string for the grouping column. If NULL (default), the analysis is performed on the full population.

eq5d_version

Version of the EQ-5D instrument

country

A character string representing the name of the country. This could be in a 2-letter format, full name or short name, as specified in the country_codes datasets.

Value

Summary plot and data used for plotting

Examples

tmp <- eq5d_utility_by_group_plot(
 example_data,
 names_eq5d = c("mo", "sc", "ua", "pd", "ad"), 
 name_groupvar = "procedure",
 eq5d_version = "3L",
 country = "UK"
)
tmp$p
tmp$plot_data

eq5dsuite documentation built on May 14, 2026, 5:07 p.m.