eq5d_utility_distribution_plot: eq5d_utility_distribution_plot: EQ-5D values: smoothed lines...

eq5d_utility_distribution_plotR Documentation

eq5d_utility_distribution_plot: EQ-5D values: smoothed lines and confidence intervals by groupvar

Description

eq5d_utility_distribution_plot: EQ-5D values: smoothed lines and confidence intervals by groupvar

Usage

eq5d_utility_distribution_plot(
  df,
  names_eq5d = NULL,
  eq5d_version = NULL,
  country
)

Arguments

df

Data frame with the EQ-5D columns

names_eq5d

Character vector of column names for the EQ-5D dimensions

eq5d_version

Version of the EQ-5D instrument

country

A character string representing the name of the country. This could be in a 2-letter format, full name or short name, as specified in the country_codes datasets.

Value

Summary plot and data used for plotting

Examples

tmp <- eq5d_utility_distribution_plot(
 example_data,
 names_eq5d = c("mo", "sc", "ua", "pd", "ad"), 
 eq5d_version = "3L",
 country = "UK"
)
tmp$p
tmp$plot_data

eq5dsuite documentation built on May 14, 2026, 5:07 p.m.