fetch_available_value_sets: Fetch the index of available value sets from GitHub

View source: R/update_value_sets.R

fetch_available_value_setsR Documentation

Fetch the index of available value sets from GitHub

Description

Fetch the index of available value sets from GitHub

Usage

fetch_available_value_sets(version)

Arguments

version

Character. One of "3L", "5L", or "Y3L".

Value

A data frame with columns Version, Name, Name_short, Country_code, VS_code, doi. Returns NULL if fetch fails.


eq5dsuite documentation built on May 14, 2026, 5:07 p.m.