figure_3_4: Figure 3.4: EQ-5D values: smoothed lines and confidence...

figure_3_4R Documentation

Figure 3.4: EQ-5D values: smoothed lines and confidence intervals by groupvar

Description

Figure 3.4: EQ-5D values: smoothed lines and confidence intervals by groupvar

Usage

figure_3_4(df, names_eq5d = NULL, eq5d_version = NULL, country)

Arguments

df

Data frame with the EQ-5D columns

names_eq5d

Character vector of column names for the EQ-5D dimensions

eq5d_version

Version of the EQ-5D instrument

country

A character string representing the name of the country. This could be in a 2-letter format, full name or short name, as specified in the country_codes datasets.

Value

Summary plot and data used for plotting

Examples

tmp <- figure_3_4(
 example_data,
 names_eq5d = c("mo", "sc", "ua", "pd", "ad"), 
 eq5d_version = "3L",
 country = "UK"
)
tmp$p
tmp$plot_data

eq5dsuite documentation built on April 11, 2026, 5:06 p.m.