| figure_3_5 | R Documentation |
Figure 3.5: EQ-5D values: smoothed lines and confidence intervals by groupvar
figure_3_5(
df,
names_eq5d = NULL,
name_vas = NULL,
eq5d_version = NULL,
country
)
df |
Data frame with the EQ-5D columns |
names_eq5d |
Character vector of column names for the EQ-5D dimensions |
name_vas |
Character string for the VAS column |
eq5d_version |
Version of the EQ-5D instrument |
country |
A character string representing the name of the country. This could be in a 2-letter format, full name or short name, as specified in the country_codes datasets. |
Summary plot and data used for plotting
tmp <- figure_3_5(
example_data,
names_eq5d = c("mo", "sc", "ua", "pd", "ad"),
name_vas = "vas",
eq5d_version = "3L",
country = "UK"
)
tmp$p
tmp$plot_data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.