get_cache_dir: Get the eq5dsuite cache directory

View source: R/cache.R

get_cache_dirR Documentation

Get the eq5dsuite cache directory

Description

Returns the path to the user-specific cache directory used by eq5dsuite to store the date of the last value set check. The directory is created if it does not exist.

Usage

get_cache_dir()

Value

A character string giving the path to the cache directory.


eq5dsuite documentation built on May 14, 2026, 5:07 p.m.