get_last_checked: Get the date of the last value set check

View source: R/cache.R

get_last_checkedR Documentation

Get the date of the last value set check

Description

Reads the cached date of the last value set update check from the user cache directory. Returns 1970-01-01 if no cache file exists (i.e., the check has never been run).

Usage

get_last_checked()

Value

A Date object.


eq5dsuite documentation built on May 14, 2026, 5:07 p.m.