is_update_due: Check whether a value set update check is due

View source: R/cache.R

is_update_dueR Documentation

Check whether a value set update check is due

Description

Compares the date of the last value set check (from the user cache) against Sys.Date(). Returns TRUE if more than threshold_days days have elapsed, indicating that the user should be prompted to run update_value_sets().

Usage

is_update_due(threshold_days = 60)

Arguments

threshold_days

A single positive integer giving the number of days after which an update check is considered overdue. Defaults to 60.

Value

A single logical value.


eq5dsuite documentation built on May 14, 2026, 5:07 p.m.