run_app: Launch the eq5dsuite Shiny Application

View source: R/run_app.R

run_appR Documentation

Launch the eq5dsuite Shiny Application

Description

Opens an interactive Shiny application for uploading, processing, analysing, and exporting EQ-5D data using the eq5dsuite package.

Usage

run_app(...)

Arguments

...

Additional arguments passed to runApp, such as port or launch.browser.

Value

Called for its side effect of launching a Shiny application. Returns invisibly.

Examples

## Not run: 
  eq5dsuite::run_app()

## End(Not run)

eq5dsuite documentation built on April 11, 2026, 5:06 p.m.