set_last_checked: Set the date of the last value set check

View source: R/cache.R

set_last_checkedR Documentation

Set the date of the last value set check

Description

Writes the given date to the user cache directory so that future calls to get_last_checked() and is_update_due() can determine how long ago the check was performed.

Usage

set_last_checked(date = Sys.Date())

Arguments

date

A Date object. Defaults to Sys.Date().

Value

Invisibly returns date.


eq5dsuite documentation built on May 14, 2026, 5:07 p.m.