| apply_pending_migrations | R Documentation |
Fetches the migrations index from the repository and applies any renames that have not yet been applied locally. This ensures that value set codes remain consistent when a country publishes a second value set and the original code needs to be disambiguated with a year suffix.
apply_pending_migrations(ask = TRUE)
ask |
Logical. Whether to ask for confirmation before applying migrations. Defaults to TRUE. |
Migrations are applied before checking for new value sets in
update_value_sets(), ensuring the local state is
consistent before any new installations.
Invisibly returns a character vector of migration IDs that were applied in this session.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.