| eq5d_profile_lss_utility_plot | R Documentation |
eq5d_profile_lss_utility_plot: EQ-5D values plotted against LSS
eq5d_profile_lss_utility_plot(
df,
names_eq5d = NULL,
eq5d_version = NULL,
country
)
df |
Data frame with the EQ-5D columns |
names_eq5d |
Character vector of column names for the EQ-5D dimensions |
eq5d_version |
Version of the EQ-5D instrument |
country |
A character string representing the name of the country. This could be in a 2-letter format, full name or short name, as specified in the country_codes datasets. |
Summary plot and data used for plotting
df <- data.frame(make_all_EQ_states(version = "5L"))
tmp <- eq5d_profile_lss_utility_plot(
df,
names_eq5d = c("mo", "sc", "ua", "pd", "ad"),
eq5d_version = "5L",
country = "US"
)
tmp$p
tmp$plot_data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.