eqvs_display: eqvs_display

View source: R/EQ_functions.R

eqvs_displayR Documentation

eqvs_display

Description

Display available value sets, which can also be used as (reverse) crosswalks.

Usage

eqvs_display(version = "5L", return_df = FALSE)

Arguments

version

Version of the EQ-5D instrument. Can take values 5L (default), 3L or 3LY.

return_df

If set to TRUE, the function will return information on the names of the available value sets in a data.frame. Defaults to FALSE

Value

Default NULL, if return_df == TRUE, returns a data.frame with the displayed information.

Examples

# Display available value sets.
eqvs_display

eq5dsuite documentation built on April 11, 2026, 5:06 p.m.