| get_cache_dir | R Documentation |
Returns the path to the user-specific cache directory used by eq5dsuite to store the date of the last value set check. The directory is created if it does not exist.
get_cache_dir()
A character string giving the path to the cache directory.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.