| is_update_due | R Documentation |
Compares the date of the last value set check (from the user cache)
against Sys.Date(). Returns TRUE if more than
threshold_days days have elapsed, indicating that the user
should be prompted to run update_value_sets().
is_update_due(threshold_days = 60)
threshold_days |
A single positive integer giving the number of
days after which an update check is considered overdue. Defaults
to |
A single logical value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.