| run_app | R Documentation |
Opens an interactive Shiny application for uploading, processing, analysing, and exporting EQ-5D data using the eq5dsuite package.
run_app(...)
... |
Additional arguments passed to |
Called for its side effect of launching a Shiny application. Returns invisibly.
## Not run:
eq5dsuite::run_app()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.