Learn R Programming

eq5dsuite (version 1.0.2)

run_app: Launch the eq5dsuite Shiny Application

Description

Opens an interactive Shiny application for uploading, processing, analysing, and exporting EQ-5D data using the eq5dsuite package.

Usage

run_app(...)

Value

Called for its side effect of launching a Shiny application. Returns invisibly.

Arguments

...

Additional arguments passed to runApp, such as port or launch.browser.

Examples

Run this code
if (FALSE) {
  eq5dsuite::run_app()
}

Run the code above in your browser using DataLab