powered by
Opens an interactive Shiny application for uploading, processing, analysing, and exporting EQ-5D data using the eq5dsuite package.
run_app(...)
Called for its side effect of launching a Shiny application. Returns invisibly.
Additional arguments passed to runApp, such as port or launch.browser.
runApp
port
launch.browser
if (FALSE) { eq5dsuite::run_app() }
Run the code above in your browser using DataLab